@@ -218,7 +218,7 @@ class PyHocaGUI_DialogBoxPassword(wx.Dialog):
             else:
                 move_y = self._PyHocaGUI.logon_window_position_y
 
-        elif (x2go.X2GOCLIENT_OS == 'Linux') and (WINDOW_MANAGER in ('gnome', 'gnome-fallback', 'awesome', 'ubuntu', 'ubuntu-2d', 'openbox-gnome', )):
+        elif (x2go.X2GOCLIENT_OS == 'Linux') and (WINDOW_MANAGER in ('gnome', 'gnome-fallback', 'awesome', 'mate', 'ubuntu', 'ubuntu-2d', 'openbox-gnome', )):
 
             # automatically place logon Window for GNOME, awesome
             move_x = maxX - (self.GetSize().GetWidth() + 20)
@@ -432,7 +432,7 @@ class PyHocaGUI_DialogBoxPassword(wx.Dialog):
                                              text=_(u'An unknown error occured during authentication!'),
                                              icon='auth_error')
             connect_failed = True
-            if os.environ.has_key('PYHOCAGUI_DEVELOPMENT') and os.environ['PYHOCAGUI_DEVELOPMENT'] == '1':
+            if self._PyHocaGUI.args.debug or self._PyHocaGUI.args.libdebug or (os.environ.has_key('PYHOCAGUI_DEVELOPMENT') and os.environ['PYHOCAGUI_DEVELOPMENT'] == '1'):
                 raise
 
         self._PyHocaGUI.notifier.send(self.current_profile_name, context='AUTH_%s' % self.current_profile_name, timeout=4000)
