@@ -968,6 +968,12 @@ class PyHocaGUI_Menu_TaskbarProfileNames(wx.Menu):
                     self.Append(text=_(u'Export Profile Group'), id=_export_id)
                 self._PyHocaGUI.Bind(wx.EVT_MENU, self._PyHocaGUI.OnProfileExport, id=_export_id)
 
+        if bind_method is None and not group_name:
+            _import_id = wx.NewId()
+            self.AppendSeparator()
+            self.Append(text=_(u'Import Session Profiles'), id=_import_id)
+            self._PyHocaGUI.Bind(wx.EVT_MENU, self._PyHocaGUI.OnProfileImport, id=_import_id)
+
     def OnUpdateUI(self, evt):
         profile_name = self._PyHocaGUI._eventid_profilenames_map[evt.GetId()]
         if profile_name in self._PyHocaGUI._temp_disabled_profile_names:
