@@ -119,7 +119,7 @@ class PyHocaGUI_DialogBoxSessionTitle(wx.Dialog):
             else:
                 move_y = self._PyHocaGUI.logon_window_position_y
 
-        elif (x2go.X2GOCLIENT_OS == 'Linux') and (WINDOW_MANAGER in ('gnome', 'gnome-fallback', 'awesome', 'ubuntu', 'ubuntu-2d', 'openbox-gnome', )):
+        elif (x2go.X2GOCLIENT_OS == 'Linux') and (WINDOW_MANAGER in ('gnome', 'gnome-fallback', 'awesome', 'mate', 'ubuntu', 'ubuntu-2d', 'openbox-gnome', )):
 
             # automatically place logon Window for GNOME, awesome
             move_x = maxX - (self.GetSize().GetWidth() + 20)
