@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2010-2012 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
-# Copyright (C) 2010-2012 by Dick Kniep <dick.kniep@lindix.nl>
+# Copyright (C) 2010-2013 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
+# Copyright (C) 2010-2013 by Dick Kniep <dick.kniep@lindix.nl>
 #
 # PyHoca GUI is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -30,7 +30,7 @@ try:
     wxversion.select('2.8')
 except: pass
 
-# Python X2go
+# Python X2Go
 import x2go
 
 import gevent
@@ -50,6 +50,35 @@ import basepath
 
 _icons_location = basepath.icons_basepath
 
+def MakeIcon(icon_name, fallback_name='pyhoca-trayicon'):
+    """\
+    The various platforms have different requirements for the
+    icon size...
+
+    @param icon_name: rel. file name of the icon image
+    @type icon_name: C{str}
+    @param fallback_name: a fallback icon file name in case C{icon_name} cannot be found
+    @type fallback_name: C{str}
+
+    """
+    if "wxMSW" in wx.PlatformInfo:
+        icon_size = '16x16'
+    elif "wxGTK" in wx.PlatformInfo:
+        icon_size = '22x22'
+    elif "wxMAC" in wx.PlatformInfo:
+        icon_size = '128x128'
+
+    if icon_name is None:
+        icon_name = fallback_name
+
+    icon_file = '%s/PyHoca/%s/%s.png' % (_icons_location, icon_size, icon_name)
+    if not (os.path.isfile(str(icon_file)) or os.path.islink(str(icon_file))):
+        icon_file = '%s/PyHoca/%s/%s.png' % (_icons_location, icon_size, fallback_name)
+
+    img = wx.Image(icon_file)
+    icon = wx.IconFromBitmap(img.ConvertToBitmap())
+    return icon
+
 
 class PyHocaGUI_TaskBarIcon(wx.TaskBarIcon):
     """\
@@ -85,12 +114,12 @@ class PyHocaGUI_TaskBarIcon(wx.TaskBarIcon):
         """
         if x2go.X2GOCLIENT_OS == 'Windows':
             icon_name = self._PyHocaGUI.tray_icon_connecting or self._PyHocaGUI.tray_icon
-            self.icon = self.MakeIcon(icon_name=icon_name, fallback_name='x2go-logo-ubuntu')
+            self.icon = MakeIcon(icon_name=icon_name, fallback_name='pyhoca-trayicon')
             self.SetIcon(self.icon, _(u"PyHoca-GUI\nConnecting you to ,,%s\'\'") % profile_name)
         else:
             icon_name = self._PyHocaGUI.tray_icon_connecting or self._PyHocaGUI.tray_icon
-            self.icon = self.MakeIcon(icon_name=icon_name, fallback_name='pyhoca-trayicon')
-            self.SetIcon(self.icon, _(u"PyHoca-GUI (Python X2goClient)\nCurrently connecting you to remote X2Go server ,,%s\'\'") % profile_name)
+            self.icon = MakeIcon(icon_name=icon_name, fallback_name='pyhoca-trayicon')
+            self.SetIcon(self.icon, _(u"PyHoca-GUI (Python X2Go Client)\nCurrently connecting you to remote X2Go server ,,%s\'\'") % profile_name)
 
     def SetIconIdle(self):
         """\
@@ -99,12 +128,12 @@ class PyHocaGUI_TaskBarIcon(wx.TaskBarIcon):
         """
         if x2go.X2GOCLIENT_OS == 'Windows':
             icon_name = self._PyHocaGUI.tray_icon
-            self.icon = self.MakeIcon(icon_name=icon_name, fallback_name='x2go-logo-ubuntu')
+            self.icon = MakeIcon(icon_name=icon_name, fallback_name='pyhoca-trayicon')
             self.SetIcon(self.icon, _(u"PyHoca-GUI\nConnecting you to X2Go..."))
         else:
             icon_name = self._PyHocaGUI.tray_icon
-            self.icon = self.MakeIcon(icon_name=icon_name, fallback_name='pyhoca-trayicon')
-            self.SetIcon(self.icon, _(u"PyHoca-GUI (Python X2goClient)\nClient for connecting you to a remote X2Go server"))
+            self.icon = MakeIcon(icon_name=icon_name, fallback_name='pyhoca-trayicon')
+            self.SetIcon(self.icon, _(u"PyHoca-GUI (Python X2Go Client)\nClient for connecting you to a remote X2Go server"))
 
     def CreateSessionManagerPopupMenu(self, evt):
         """\
@@ -148,35 +177,6 @@ class PyHocaGUI_TaskBarIcon(wx.TaskBarIcon):
         self.menu_optionsmanager = self.PopupMenu(menus_taskbar.PyHocaGUI_Menu_TaskbarOptionsManager(self._PyHocaGUI, caller=self,))
         return self.menu_optionsmanager
 
-    def MakeIcon(self, icon_name, fallback_name='pyhoca-trayicon'):
-        """\
-        The various platforms have different requirements for the
-        icon size...
-
-        @param icon_name: rel. file name of the icon image
-        @type icon_name: C{str}
-        @param fallback_name: a fallback icon file name in case C{icon_name} cannot be found
-        @type fallback_name: C{str}
-
-        """
-        if "wxMSW" in wx.PlatformInfo:
-            icon_size = '16x16'
-        elif "wxGTK" in wx.PlatformInfo:
-            icon_size = '22x22'
-        elif "wxMAC" in wx.PlatformInfo:
-            icon_size = '128x128'
-
-        if icon_name is None:
-            icon_name = fallback_name
-
-        icon_file = '%s/PyHoca/%s/%s.png' % (_icons_location, icon_size, icon_name)
-        if not (os.path.isfile(str(icon_file)) or os.path.islink(str(icon_file))):
-            icon_file = '%s/PyHoca/%s/%s.png' % (_icons_location, icon_size, fallback_name)
-
-        img = wx.Image(icon_file)
-        icon = wx.IconFromBitmap(img.ConvertToBitmap())
-        return icon
-
     def Close(self):
         """\
         Remove the applet icon from the system tray.
